==> haskell-mockery-0.3.5-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-H3WlWyxJk5ADCc8GLFLtqL
key: mockery-0.3.5-H3WlWyxJk5ADCc8GLFLtqL
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: 0d33ddc35adb3a52847e44917ab06d01
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.4.3/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-H3WlWyxJk5ADCc8GLFLtqL
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2 temporary-1.3-9oQzo4JVNP7CXkKVrv2cKm
    directory-1.3.1.5 filepath-1.4.2
    logging-facade-0.3.0-4gnXP6GGYSQATy8alz82JA
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             temporary-1.3-9oQzo4JVNP7CXkKVrv2cKm=ea3af39ce8ca8ee514ec8c391cc2de11
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             logging-facade-0.3.0-4gnXP6GGYSQATy8alz82JA=a63f83b1603648815ac3f8fd3dc11596
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-JAq5aHj1FIL8K3NRxJC8d0
key: mockery-0.3.5-JAq5aHj1FIL8K3NRxJC8d0
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: 483a1093a52756a554122c5e92025ed0
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.4.3/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-JAq5aHj1FIL8K3NRxJC8d0
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2 temporary-1.3-JxV7dEpTppeGXaZqSEN7re
    directory-1.3.1.5 filepath-1.4.2
    logging-facade-0.3.0-K9MLU81SoYhEF8ffzrGA0k
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             temporary-1.3-JxV7dEpTppeGXaZqSEN7re=771c55cbbdd451ecc55a6b35f8825c75
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             logging-facade-0.3.0-K9MLU81SoYhEF8ffzrGA0k=4eeb60f43e53ed582dc6f673f5eae7cf
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
